==> haskell-yaml-0.11.11.2-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-4MoiGONAAOECgm0j0bgnYj
key:                  yaml-0.11.11.2-4MoiGONAAOECgm0j0bgnYj
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  ac4b0bd37e7800f06858b23753f65a80
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-4MoiGONAAOECgm0j0bgnYj
depends:
    aeson-2.1.2.1-F8ZePgr6g4xL6kF4wsQx0x
    attoparsec-0.14.4-D7CECqktDgS2fYWStxbJq3 base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-Iv674JaqEE17PR7slCoUfp
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    libyaml-0.1.4-CAx32aw2uGTXPAAxse4k8 mtl-2.2.2
    resourcet-1.2.6-1uUyorfyzWb8h78koH6NVM
    scientific-0.3.8.0-IrrbGrT9lim10QS5UtlqtE template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.11.2-176-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-1K4UmsabMqiEDmJhHUW5y4
key:                  yaml-0.11.11.2-1K4UmsabMqiEDmJhHUW5y4
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  a69f585b8ea89893e3098dacae65a0d2
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-1K4UmsabMqiEDmJhHUW5y4
depends:
    aeson-2.1.2.1-IZ8jLcnEISD7S5Vyf2Tehm
    attoparsec-0.14.4-IXbcbJGX0cBC8WVvSy4ntj base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-6EN3TiAZvJYIfvMY9NMvKR
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    libyaml-0.1.4-HBavXobuKzS4zRo7UqxO1U mtl-2.2.2
    resourcet-1.2.6-98QeMzdnC7kQabpsrpmbK
    scientific-0.3.8.0-JtTPeMck4RoCJw8PpYbrMQ template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-79maJZZuZDu8bRI1CHuoJG
    vector-0.13.2.0-9TreTxHfwqF7cSCfMWPj9u

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
